@@ -1,5 +1,7 @@
 package App::CharmKit;
-$App::CharmKit::VERSION = '2.04';
+$App::CharmKit::VERSION = '2.05';
+# ABSTRACT: ezpz Juju charm authoring
+
 use strict;
 use warnings;
 use App::Cmd::Setup -app;
@@ -12,7 +14,7 @@ __END__
 
 =head1 NAME
 
-App::CharmKit
+App::CharmKit - ezpz Juju charm authoring
 
 =head1 AUTHOR
 
